==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Input/cue/translations/cue_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="40"/>
        <source>CUE Plugin</source>
        <translation>Plugin CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="43"/>
        <source>CUE Files</source>
        <translation>File CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="93"/>
        <source>About CUE Audio Plugin</source>
        <translation>Tentang Plugin Audio CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="94"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Plugin Audio CUE Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Setelan Plugin CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Setelan umum</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Muat sheetts cue yang salah jika memungkinkan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Pengkodean CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Deteksi charset otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Bahasa:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Pengkodean baku:</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.2.orig.tar.bz2: qmmp-1.2.2/src/plugins/Input/cue/translations/cue_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="39"/>
        <source>CUE Plugin</source>
        <translation>Plugin CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="42"/>
        <source>CUE Files</source>
        <translation>File CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="91"/>
        <source>About CUE Audio Plugin</source>
        <translation>Tentang Plugin Audio CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="92"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Plugin Audio CUE Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="93"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Setelan Plugin CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Setelan umum</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Muat sheetts cue yang salah jika memungkinkan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Pengkodean CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Deteksi charset otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Bahasa:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Pengkodean baku:</translation>
    </message>
</context>
</TS>
